@@ -21,13 +21,21 @@
 #ifndef _GIAC_FIRST_H_
 #define _GIAC_FIRST_H_
 
+#ifdef NUMWORKS
+#define KHICAS 1
+#endif
+
 #ifndef GIAC_VERSION
 #define GIAC_VERSION VERSION
 #endif
 //#include <stdint.h>
 
-#ifdef __x86_64__
+#if defined(__x86_64__) || defined(__arm64__)
 #define x86_64 1
+#else
+#ifdef __MINGW_H
+#define MINGW32
+#endif
 #endif
 
 // Thanks to Jason Papadopoulos, author of msieve
@@ -55,6 +63,8 @@
 #define NO_STDEXCEPT 1
 #endif
 
+#define MAX_INTSTACK 32768 // maximal size for allocating an array by int tab[]
+
 #ifdef FXCG
 #define RAND_MAX 2147483647
 #define clock() 0
@@ -87,7 +97,7 @@ double lgamma(double);
 #else // NSPIRE
 #define CIN std::cin
 #define COUT std::cout
-#ifdef EMCC
+#if defined(EMCC) || defined(EMCC2)
 #define CERR std::cout
 extern "C" double emcctime(); 
 extern "C" int glinit(int,int,int,int,int);
@@ -128,6 +138,8 @@ typedef long double giac_double;
 typedef double giac_double;
 #endif
 
+typedef long double  long_double;
+
 // sprintf replacement
 int my_sprintf(char * s, const char * format, ...);
 #ifdef GIAC_HAS_STO_38
@@ -137,8 +149,13 @@ int my_sprintf(char * s, const char * format, ...);
 #ifdef WITH_MYOSTREAM
 #include "myostream.h"
 #else
+#if defined KHICAS //&& defined STATIC_BUILTIN_LEXER_FUNCTION
+#include "stdstream"
+#define my_ostream stdostream
+#else
 #define my_ostream std::ostream
 #endif
+#endif
 
 #ifdef x86_64
 #define alias_type ulonglong
@@ -146,7 +163,7 @@ int my_sprintf(char * s, const char * format, ...);
 #define alias_type size_t
 #endif
 
-#if defined(RTOS_THREADX) || defined(BESTA_OS) || defined NSPIRE
+#if defined(RTOS_THREADX) || defined(BESTA_OS) || defined NSPIRE || defined KHICAS
 #define NO_TEMPLATE_MULTGCD
 #endif
 
@@ -157,7 +174,7 @@ int my_sprintf(char * s, const char * format, ...);
 #define CLOCK_T int
 #endif
 
-#if !defined HAVE_ALLOCA_H && !defined GIAC_HAS_STO_38
+#if !defined HAVE_ALLOCA_H && !defined GIAC_HAS_STO_38 && !defined KHICAS
 #define alloca _alloca
 #endif
 
@@ -272,8 +289,8 @@ typedef unsigned __int64 ulonglong ;
 typedef long long longlong;
 typedef unsigned long long ulonglong;
 #ifdef x86_64
-  typedef int int128_t __attribute__((mode(TI)));
-  typedef unsigned int uint128_t __attribute__((mode(TI)));
+typedef int int128_t __attribute__((mode(TI)));
+typedef unsigned int uint128_t __attribute__((mode(TI)));
 #ifndef INT128
 #define INT128 1
 #endif
@@ -293,6 +310,7 @@ typedef unsigned long long ulonglong;
 
 #endif // __VISUALC__
 
+
 #ifdef VISUALC
 inline void swap_giac_double(double & a,double & b){ double c=a; a=b; b=c; }
 #else
@@ -519,7 +537,7 @@ inline float ffloor(float f1){
 #endif
 }
 inline float finv(float f1){ return 1/f1; }
-#if defined __APPLE__ || defined EMCC || defined NO_BSD 
+#if defined __APPLE__ || defined EMCC || defined EMCC2 || defined NO_BSD 
 inline float fgamma(float f1){ return tgammaf(f1); }
 #else
 #if defined(__MINGW_H) || defined(VISUALC) || defined(FXCG)// FIXME gamma, not used
