@@ -27,6 +27,11 @@
 #include <sys/time.h>
 #endif
 
+#ifdef __MINGW_H
+inline int setenv(const char *name, const char *value, int overwrite){ return 0;}
+inline int unsetenv(const char *name){return 0;}
+#endif
+
 #ifndef NO_NAMESPACE_GIAC
 namespace giac {
 #endif // ndef NO_NAMESPACE_GIAC
@@ -283,7 +288,10 @@ namespace giac {
   extern const unary_function_ptr * const  at_pop;
   extern const unary_function_ptr * const  at_coth ;
   extern const unary_function_ptr * const  at_atan2 ;
+  vecteur get_pixel_v();
+  void adjust_pixels_dim(const vecteur & V,int & I,int &J);
   extern const unary_function_ptr * const  at_get_pixel ;
+  extern int screen_w,screen_h;
   gen _set_pixel(const gen & args,GIAC_CONTEXT);
   gen _get_pixel(const gen & args,GIAC_CONTEXT);
   gen _draw_string(const gen & a_,GIAC_CONTEXT);
@@ -295,6 +303,8 @@ namespace giac {
   extern const unary_function_ptr * const  at_isfinite ;
   extern const unary_function_ptr * const  at_isnan ;
   extern const unary_function_ptr * const  at_draw_string ;
+  extern const unary_function_ptr * const  at_draw_filled_circle ;
+  extern const unary_function_ptr * const  at_draw_filled_arc ;
   extern const unary_function_ptr * const  at_dtype ;
   extern const unary_function_ptr * const  at_rgb ;
   extern const unary_function_ptr * const  at_prediction;
@@ -310,6 +320,10 @@ namespace giac {
   extern const unary_function_ptr * const  at_rm ;
   int rgb888to565(int c);
   int rgb565to888(int c);
+#if defined HAVE_UNISTD_H && !defined NUMWORKS
+  int cp(const char * sourcename,const char * targetname);
+  int rm(const char * filename);
+#endif
 
   gen _show_pixels(const gen & args,GIAC_CONTEXT);
   gen _rgb(const gen & args,GIAC_CONTEXT);
